leaftools.remove_terminal_rests_from_sequence
=============================================

.. autofunction:: abjad.tools.leaftools.remove_terminal_rests_from_sequence.remove_terminal_rests_from_sequence
